@@ -3,6 +3,8 @@ set -e
 
 if [ "x$DJANGO_MANAGEPY_MIGRATE" = 'xon' ]; then
     python manage.py migrate --noinput
+    python manage.py installwatson
+    python manage.py buildwatson
 fi
 
-exec "$@"
\ No newline at end of file
+exec "$@"
