@@ -1,23 +1,23 @@
-from django.forms import ModelForm
-from django import forms
-from django_currentuser.middleware import (get_current_user, get_current_authenticated_user)
-from crispy_forms.helper import FormHelper
-from crispy_forms.layout import Layout, Fieldset, ButtonHolder, Submit, Div, Row, Button
-from crispy_forms.bootstrap import FormActions, AppendedText, InlineCheckboxes, PrependedText
 import sys
+from django.forms import ModelForm
+from django_currentuser.middleware import get_current_user
+from crispy_forms.helper import FormHelper
+from crispy_forms.layout import Layout, Fieldset, Submit, Div
+from crispy_forms.bootstrap import FormActions, AppendedText, InlineCheckboxes, PrependedText, TabHolder, Tab
 
 from schema.models import Accessory, Archive, Battery, BulkFilm, Camera, CameraModel, Developer, Enlarger, FilmStock, Filter
 from schema.models import Flash, FlashProtocol, Format, Lens, LensModel, Manufacturer
-from schema.models import Mount, MountAdapter, NegativeSize, Order, PaperStock, Person, Print, Toning
-from schema.models import Process, Repair, Scan, Negative, Film, Series, ShutterSpeed, Teleconverter, Toner
+from schema.models import Mount, MountAdapter, NegativeSize, Order, PaperStock, Person, Print
+from schema.models import Process, Repair, Scan, Negative, Film, Teleconverter, Toner
+
 
 class AccessoryForm(ModelForm):
     class Meta:
         model = Accessory
         fields = [
-            'type',
             'manufacturer',
             'model',
+            'type',
             'acquired',
             'cost',
             'lost',
@@ -29,27 +29,37 @@ class AccessoryForm(ModelForm):
             fields.remove('manufacturer')
             fields.remove('camera_model_compatibility')
             fields.remove('lens_model_compatibility')
+
     def __init__(self, *args, **kwargs):
         super(AccessoryForm, self).__init__(*args, **kwargs)
         self.helper = FormHelper(self)
         self.helper.layout.append(Submit('Save', 'Save'))
 
+
 class ArchiveForm(ModelForm):
     class Meta:
         model = Archive
-        fields = [
-            'type',
-            'name',
-            'max_width',
-            'max_height',
-            'location',
-            'storage',
-            'sealed',
-        ]
+        fields = '__all__'
+
     def __init__(self, *args, **kwargs):
         super(ArchiveForm, self).__init__(*args, **kwargs)
         self.helper = FormHelper(self)
-        self.helper.layout.append(Submit('Save', 'Save'))
+        self.helper.layout = Layout(
+            Div(
+                'name',
+                'type',
+                AppendedText('max_width', '"'),
+                AppendedText('max_height', '"'),
+                'location',
+                'storage',
+                'sealed',
+            ),
+            FormActions(
+                Submit('save', 'Save'),
+            )
+        )
+
+
 
 class BatteryForm(ModelForm):
     class Meta:
@@ -58,13 +68,15 @@ class BatteryForm(ModelForm):
             'name',
             'voltage',
             'chemistry',
-            'other_names',
+            'compatible_with',
         ]
+
     def __init__(self, *args, **kwargs):
         super(BatteryForm, self).__init__(*args, **kwargs)
         self.helper = FormHelper(self)
         self.helper.layout.append(Submit('Save', 'Save'))
 
+
 class BulkFilmForm(ModelForm):
     class Meta:
         model = BulkFilm
@@ -80,11 +92,13 @@ class BulkFilmForm(ModelForm):
         if ('makemigrations' in sys.argv or 'migrate' in sys.argv or 'test' in sys.argv):
             fields.remove('filmstock')
             fields.remove('format')
+
     def __init__(self, *args, **kwargs):
         super(BulkFilmForm, self).__init__(*args, **kwargs)
         self.helper = FormHelper(self)
         self.helper.layout.append(Submit('Save', 'Save'))
 
+
 class CameraForm(ModelForm):
     class Meta:
         model = Camera
@@ -96,28 +110,27 @@ class CameraForm(ModelForm):
             'datecode',
             'manufactured',
             'own',
-            'lens',
             'notes',
             'lost',
             'lost_price',
             'source',
             'condition',
             'condition_notes',
-            'display_lens',
         ]
         if ('makemigrations' in sys.argv or 'migrate' in sys.argv or 'test' in sys.argv):
             fields.remove('cameramodel')
+
     def __init__(self, *args, **kwargs):
         super(CameraForm, self).__init__(*args, **kwargs)
-        self.fields['lens'].queryset = Lens.objects.filter(owner = get_current_user())
-        self.fields['display_lens'].queryset = Lens.objects.filter(owner = get_current_user())
         self.helper = FormHelper(self)
         self.helper.layout.append(Submit('Save', 'Save'))
 
+
 class CameraModelForm(ModelForm):
     class Meta:
         model = CameraModel
         fields = '__all__'
+
     def __init__(self, *args, **kwargs):
         super(CameraModelForm, self).__init__(*args, **kwargs)
         self.helper = FormHelper(self)
@@ -130,12 +143,55 @@ class CameraModelForm(ModelForm):
                 'disambiguation',
                 'introduced',
                 'discontinued',
-                'mount',
-                'fixed_mount',
-                'lensmodel',
                 'format',
                 'negative_size',
             ),
+            Div(
+                TabHolder(
+                    Tab('Interchangeable lens',
+                        Fieldset(
+                            'Lens mount',
+                            'mount',
+                        ),
+                        ),
+                    Tab('Fixed lens',
+                        Fieldset(
+                            'Lens',
+                            'lens_manufacturer',
+                            'lens_model_name',
+                        ),
+                        Fieldset(
+                            'Optics',
+                            'zoom',
+                            AppendedText('min_focal_length', 'mm'),
+                            AppendedText('max_focal_length', 'mm'),
+                            AppendedText('closest_focus', 'cm'),
+                            PrependedText('max_aperture', 'f/'),
+                            PrependedText('min_aperture', 'f/'),
+                            'elements',
+                            'groups',
+                            AppendedText('nominal_min_angle_diag', '&deg;'),
+                            AppendedText('nominal_max_angle_diag', '&deg;'),
+                            'rectilinear',
+                            AppendedText('image_circle', 'mm'),
+                            'formula',
+                            'aperture_blades',
+                            'coating',
+                            AppendedText('magnification', '&times;'),
+                        ),
+                        Fieldset(
+                            'Physical',
+                            AppendedText('filter_thread', 'mm'),
+                            'hood',
+                        ),
+                        Fieldset(
+                            'Misc',
+                            'exif_lenstype',
+                        ),
+                        ),
+                ),
+                css_class="border",
+            ),
             Fieldset(
                 'Physical',
                 'body_type',
@@ -150,7 +206,6 @@ class CameraModelForm(ModelForm):
             Fieldset(
                 'Metering',
                 'metering',
-                'coupled_metering',
                 'metering_type',
                 InlineCheckboxes('metering_modes'),
                 InlineCheckboxes('exposure_programs'),
@@ -175,6 +230,7 @@ class CameraModelForm(ModelForm):
                 'flash_metering',
                 'pc_sync',
                 'shoe',
+                'x_sync',
             ),
             Fieldset(
                 'Battery',
@@ -185,6 +241,7 @@ class CameraModelForm(ModelForm):
                 'Features',
                 'cable_release',
                 'dof_preview',
+                'mirror_lockup',
                 'tripod',
                 'power_drive',
                 AppendedText('continuous_fps', 'fps'),
@@ -192,14 +249,15 @@ class CameraModelForm(ModelForm):
             Fieldset(
                 'Misc',
                 'notes',
-                'series',
+                'tags',
+                'url',
             ),
             FormActions(
-                Submit('save', 'Save changes'),
-                Button('cancel', 'Cancel')
+                Submit('save', 'Save')
             )
         )
 
+
 class DeveloperForm(ModelForm):
     class Meta:
         model = Developer
@@ -209,14 +267,17 @@ class DeveloperForm(ModelForm):
             'for_paper',
             'for_film',
             'chemistry',
+            'tags',
         ]
         if ('makemigrations' in sys.argv or 'migrate' in sys.argv or 'test' in sys.argv):
             fields.remove('manufacturer')
+
     def __init__(self, *args, **kwargs):
         super(DeveloperForm, self).__init__(*args, **kwargs)
         self.helper = FormHelper(self)
         self.helper.layout.append(Submit('Save', 'Save'))
 
+
 class EnlargerForm(ModelForm):
     class Meta:
         model = Enlarger
@@ -236,11 +297,13 @@ class EnlargerForm(ModelForm):
         if ('makemigrations' in sys.argv or 'migrate' in sys.argv or 'test' in sys.argv):
             fields.remove('manufacturer')
             fields.remove('negative_size')
+
     def __init__(self, *args, **kwargs):
         super(EnlargerForm, self).__init__(*args, **kwargs)
         self.helper = FormHelper(self)
         self.helper.layout.append(Submit('Save', 'Save'))
 
+
 class FilmStockForm(ModelForm):
     class Meta:
         model = FilmStock
@@ -251,38 +314,39 @@ class FilmStockForm(ModelForm):
             'colour',
             'panchromatic',
             'process',
+            'tags',
         ]
         if ('makemigrations' in sys.argv or 'migrate' in sys.argv or 'test' in sys.argv):
             fields.remove('manufacturer')
             fields.remove('process')
+
     def __init__(self, *args, **kwargs):
         super(FilmStockForm, self).__init__(*args, **kwargs)
         self.helper = FormHelper(self)
         self.helper.layout.append(Submit('Save', 'Save'))
 
+
 class FilterForm(ModelForm):
     class Meta:
         model = Filter
         fields = [
             'type',
-            'thread',
+            'shortname',
             'attenuation',
-            'qty',
-            'manufacturer',
         ]
-        if ('makemigrations' in sys.argv or 'migrate' in sys.argv or 'test' in sys.argv):
-            fields.remove('manufacturer')
+
     def __init__(self, *args, **kwargs):
         super(FilterForm, self).__init__(*args, **kwargs)
         self.helper = FormHelper(self)
         self.helper.layout.append(Submit('Save', 'Save'))
 
+
 class FlashForm(ModelForm):
     class Meta:
         model = Flash
         fields = [
-            'model',
             'manufacturer',
+            'model',
             'guide_number',
             'gn_info',
             'battery_powered',
@@ -306,11 +370,13 @@ class FlashForm(ModelForm):
             fields.remove('manufacturer')
             fields.remove('flash_protocol')
             fields.remove('battery_type')
+
     def __init__(self, *args, **kwargs):
         super(FlashForm, self).__init__(*args, **kwargs)
         self.helper = FormHelper(self)
         self.helper.layout.append(Submit('Save', 'Save'))
 
+
 class FlashProtocolForm(ModelForm):
     class Meta:
         model = FlashProtocol
@@ -320,11 +386,13 @@ class FlashProtocolForm(ModelForm):
         ]
         if ('makemigrations' in sys.argv or 'migrate' in sys.argv or 'test' in sys.argv):
             fields.remove('manufacturer')
+
     def __init__(self, *args, **kwargs):
         super(FlashProtocolForm, self).__init__(*args, **kwargs)
         self.helper = FormHelper(self)
         self.helper.layout.append(Submit('Save', 'Save'))
 
+
 class FormatForm(ModelForm):
     class Meta:
         model = Format
@@ -334,11 +402,13 @@ class FormatForm(ModelForm):
         ]
         if ('makemigrations' in sys.argv or 'migrate' in sys.argv or 'test' in sys.argv):
             fields.remove('negative_size')
+
     def __init__(self, *args, **kwargs):
         super(FormatForm, self).__init__(*args, **kwargs)
         self.helper = FormHelper(self)
         self.helper.layout.append(Submit('Save', 'Save'))
 
+
 class LensForm(ModelForm):
     class Meta:
         model = Lens
@@ -359,15 +429,18 @@ class LensForm(ModelForm):
         ]
         if ('makemigrations' in sys.argv or 'migrate' in sys.argv or 'test' in sys.argv):
             fields.remove('lensmodel')
+
     def __init__(self, *args, **kwargs):
         super(LensForm, self).__init__(*args, **kwargs)
         self.helper = FormHelper(self)
         self.helper.layout.append(Submit('Save', 'Save'))
 
+
 class LensModelForm(ModelForm):
     class Meta:
         model = LensModel
         fields = '__all__'
+
     def __init__(self, *args, **kwargs):
         super(LensModelForm, self).__init__(*args, **kwargs)
         self.helper = FormHelper(self)
@@ -377,7 +450,6 @@ class LensModelForm(ModelForm):
                 'manufacturer',
                 'model',
                 'disambiguation',
-                'fixed_mount',
                 'mount',
                 'introduced',
                 'discontinued',
@@ -398,6 +470,7 @@ class LensModelForm(ModelForm):
                 AppendedText('image_circle', 'mm'),
                 'formula',
                 'aperture_blades',
+                'coating',
                 'autofocus',
                 AppendedText('magnification', '&times;'),
                 'negative_size',
@@ -414,15 +487,15 @@ class LensModelForm(ModelForm):
             Fieldset(
                 'Misc',
                 'notes',
+                'tags',
                 'exif_lenstype',
                 'url',
-                'series',
             ),
             FormActions(
-                Submit('save', 'Save changes'),
-                Button('cancel', 'Cancel')
+                Submit('save', 'Save')
             )
-        )   
+        )
+
 
 class ManufacturerForm(ModelForm):
     class Meta:
@@ -434,12 +507,15 @@ class ManufacturerForm(ModelForm):
             'url',
             'founded',
             'dissolved',
+            'tags',
         ]
+
     def __init__(self, *args, **kwargs):
         super(ManufacturerForm, self).__init__(*args, **kwargs)
         self.helper = FormHelper(self)
         self.helper.layout.append(Submit('Save', 'Save'))
 
+
 class MountForm(ModelForm):
     class Meta:
         model = Mount
@@ -450,14 +526,17 @@ class MountForm(ModelForm):
             'purpose',
             'notes',
             'manufacturer',
+            'tags',
         ]
         if ('makemigrations' in sys.argv or 'migrate' in sys.argv or 'test' in sys.argv):
             fields.remove('manufacturer')
+
     def __init__(self, *args, **kwargs):
         super(MountForm, self).__init__(*args, **kwargs)
         self.helper = FormHelper(self)
         self.helper.layout.append(Submit('Save', 'Save'))
 
+
 class MountAdapterForm(ModelForm):
     class Meta:
         model = MountAdapter
@@ -471,11 +550,13 @@ class MountAdapterForm(ModelForm):
         if ('makemigrations' in sys.argv or 'migrate' in sys.argv or 'test' in sys.argv):
             fields.remove('camera_mount')
             fields.remove('lens_mount')
+
     def __init__(self, *args, **kwargs):
         super(MountAdapterForm, self).__init__(*args, **kwargs)
         self.helper = FormHelper(self)
         self.helper.layout.append(Submit('Save', 'Save'))
 
+
 class NegativeSizeForm(ModelForm):
     class Meta:
         model = NegativeSize
@@ -484,20 +565,26 @@ class NegativeSizeForm(ModelForm):
             'width',
             'height',
         ]
+
     def __init__(self, *args, **kwargs):
         super(NegativeSizeForm, self).__init__(*args, **kwargs)
         self.helper = FormHelper(self)
         self.helper.layout.append(Submit('Save', 'Save'))
 
+
 class OrderForm(ModelForm):
     def __init__(self, *args, **kwargs):
         super(OrderForm, self).__init__(*args, **kwargs)
-        self.fields['negative'].queryset = Negative.objects.filter(owner = get_current_user())
-        self.fields['print'].queryset = Print.objects.filter(owner = get_current_user())
-        self.fields['recipient'].queryset = Person.objects.filter(owner = get_current_user())
-    
+        self.fields['negative'].queryset = Negative.objects.filter(
+            owner=get_current_user())
+        self.fields['print'].queryset = Print.objects.filter(
+            owner=get_current_user())
+        self.fields['recipient'].queryset = Person.objects.filter(
+            owner=get_current_user())
+
         self.helper = FormHelper(self)
         self.helper.layout.append(Submit('Save', 'Save'))
+
     class Meta:
         model = Order
         fields = [
@@ -510,6 +597,7 @@ class OrderForm(ModelForm):
             'recipient',
         ]
 
+
 class PaperStockForm(ModelForm):
     class Meta:
         model = PaperStock
@@ -517,36 +605,46 @@ class PaperStockForm(ModelForm):
             'name',
             'manufacturer',
             'resin_coated',
-            'tonable',
             'colour',
             'finish',
+            'tags',
         ]
         if ('makemigrations' in sys.argv or 'migrate' in sys.argv or 'test' in sys.argv):
             fields.remove('manufacturer')
+
     def __init__(self, *args, **kwargs):
         super(PaperStockForm, self).__init__(*args, **kwargs)
         self.helper = FormHelper(self)
         self.helper.layout.append(Submit('Save', 'Save'))
 
+
 class PersonForm(ModelForm):
     class Meta:
         model = Person
         fields = ['name']
+
     def __init__(self, *args, **kwargs):
         super(PersonForm, self).__init__(*args, **kwargs)
         self.helper = FormHelper(self)
         self.helper.layout.append(Submit('Save', 'Save'))
 
+
 class PrintForm(ModelForm):
     def __init__(self, *args, **kwargs):
         super(PrintForm, self).__init__(*args, **kwargs)
-        self.fields['negative'].queryset = Negative.objects.filter(owner = get_current_user())
-        self.fields['enlarger'].queryset = Enlarger.objects.filter(owner = get_current_user())
-        self.fields['lens'].queryset = Lens.objects.filter(owner = get_current_user())
-        self.fields['archive'].queryset = Archive.objects.filter(owner = get_current_user())
-        self.fields['printer'].queryset = Person.objects.filter(owner = get_current_user())
+        self.fields['negative'].queryset = Negative.objects.filter(
+            owner=get_current_user())
+        self.fields['enlarger'].queryset = Enlarger.objects.filter(
+            owner=get_current_user())
+        self.fields['lens'].queryset = Lens.objects.filter(
+            owner=get_current_user())
+        self.fields['archive'].queryset = Archive.objects.filter(
+            owner=get_current_user())
+        self.fields['printer'].queryset = Person.objects.filter(
+            owner=get_current_user())
         self.helper = FormHelper(self)
         self.helper.layout.append(Submit('Save', 'Save'))
+
     class Meta:
         model = Print
         fields = [
@@ -576,6 +674,7 @@ class PrintForm(ModelForm):
             fields.remove('developer')
             fields.remove('toner')
 
+
 class ProcessForm(ModelForm):
     class Meta:
         model = Process
@@ -584,18 +683,23 @@ class ProcessForm(ModelForm):
             'colour',
             'positive',
         ]
+
     def __init__(self, *args, **kwargs):
         super(ProcessForm, self).__init__(*args, **kwargs)
         self.helper = FormHelper(self)
         self.helper.layout.append(Submit('Save', 'Save'))
 
+
 class RepairForm(ModelForm):
     def __init__(self, *args, **kwargs):
         super(RepairForm, self).__init__(*args, **kwargs)
-        self.fields['camera'].queryset = Camera.objects.filter(owner = get_current_user())
-        self.fields['lens'].queryset = Lens.objects.filter(owner = get_current_user())
+        self.fields['camera'].queryset = Camera.objects.filter(
+            owner=get_current_user())
+        self.fields['lens'].queryset = Lens.objects.filter(
+            owner=get_current_user())
         self.helper = FormHelper(self)
         self.helper.layout.append(Submit('Save', 'Save'))
+
     class Meta:
         model = Repair
         fields = [
@@ -606,13 +710,17 @@ class RepairForm(ModelForm):
             'detail',
         ]
 
+
 class ScanForm(ModelForm):
     def __init__(self, *args, **kwargs):
         super(ScanForm, self).__init__(*args, **kwargs)
-        self.fields['negative'].queryset = Negative.objects.filter(owner = get_current_user())
-        self.fields['print'].queryset = Print.objects.filter(owner = get_current_user())
+        self.fields['negative'].queryset = Negative.objects.filter(
+            owner=get_current_user())
+        self.fields['print'].queryset = Print.objects.filter(
+            owner=get_current_user())
         self.helper = FormHelper(self)
         self.helper.layout.append(Submit('Save', 'Save'))
+
     class Meta:
         model = Scan
         fields = [
@@ -625,17 +733,25 @@ class ScanForm(ModelForm):
             'height',
         ]
 
+
 class NegativeForm(ModelForm):
     def __init__(self, *args, **kwargs):
         super(NegativeForm, self).__init__(*args, **kwargs)
-        self.fields['film'].queryset = Film.objects.filter(owner = get_current_user())
-        self.fields['lens'].queryset = Lens.objects.filter(owner = get_current_user())
-        self.fields['mount_adapter'].queryset = MountAdapter.objects.filter(owner = get_current_user())
-        self.fields['film'].queryset = Film.objects.filter(owner = get_current_user())
-        self.fields['photographer'].queryset = Person.objects.filter(owner = get_current_user())
-        self.fields['copy_of'].queryset = Negative.objects.filter(owner = get_current_user())
+        self.fields['film'].queryset = Film.objects.filter(
+            owner=get_current_user())
+        self.fields['lens'].queryset = Lens.objects.filter(
+            owner=get_current_user())
+        self.fields['mount_adapter'].queryset = MountAdapter.objects.filter(
+            owner=get_current_user())
+        self.fields['film'].queryset = Film.objects.filter(
+            owner=get_current_user())
+        self.fields['photographer'].queryset = Person.objects.filter(
+            owner=get_current_user())
+        self.fields['copy_of'].queryset = Negative.objects.filter(
+            owner=get_current_user())
         self.helper = FormHelper(self)
         self.helper.layout.append(Submit('Save', 'Save'))
+
     class Meta:
         model = Negative
         fields = [
@@ -660,15 +776,21 @@ class NegativeForm(ModelForm):
             'copy_of',
         ]
 
+
 class FilmForm(ModelForm):
     def __init__(self, *args, **kwargs):
         super(FilmForm, self).__init__(*args, **kwargs)
-        self.fields['camera'].queryset = Camera.objects.filter(owner = get_current_user())
-        self.fields['bulk_film'].queryset = BulkFilm.objects.filter(owner = get_current_user())
-        self.fields['processed_by'].queryset = Person.objects.filter(owner = get_current_user())
-        self.fields['archive'].queryset = Archive.objects.filter(owner = get_current_user())
+        self.fields['camera'].queryset = Camera.objects.filter(
+            owner=get_current_user())
+        self.fields['bulk_film'].queryset = BulkFilm.objects.filter(
+            owner=get_current_user())
+        self.fields['processed_by'].queryset = Person.objects.filter(
+            owner=get_current_user())
+        self.fields['archive'].queryset = Archive.objects.filter(
+            owner=get_current_user())
         self.helper = FormHelper(self)
         self.helper.layout.append(Submit('Save', 'Save'))
+
     class Meta:
         model = Film
         fields = [
@@ -701,34 +823,31 @@ class FilmForm(ModelForm):
             fields.remove('developer')
             fields.remove('format')
 
-class SeriesForm(ModelForm):
-    class Meta:
-        model = Series
-        fields = ['name']
-    def __init__(self, *args, **kwargs):
-        super(SeriesForm, self).__init__(*args, **kwargs)
-        self.helper = FormHelper(self)
-        self.helper.layout.append(Submit('Save', 'Save'))
 
 class TeleconverterForm(ModelForm):
     class Meta:
         model = Teleconverter
-        fields = [
-            'model',
-            'manufacturer',
-            'mount',
-            'factor',
-            'elements',
-            'groups',
-            'multicoated',
-        ]
-        if ('makemigrations' in sys.argv or 'migrate' in sys.argv or 'test' in sys.argv):
-            fields.remove('manufacturer')
-            fields.remove('mount')
+        fields = '__all__'
+
     def __init__(self, *args, **kwargs):
         super(TeleconverterForm, self).__init__(*args, **kwargs)
         self.helper = FormHelper(self)
-        self.helper.layout.append(Submit('Save', 'Save'))
+        self.helper.layout = Layout(
+            Fieldset(
+                'Basics',
+                'model',
+                'manufacturer',
+                'mount',
+                AppendedText('factor', '&times;'),
+                'elements',
+                'groups',
+                'multicoated',
+            ),
+            FormActions(
+                Submit('save', 'Save')
+            )
+        )
+
 
 class TonerForm(ModelForm):
     class Meta:
@@ -738,9 +857,11 @@ class TonerForm(ModelForm):
             'manufacturer',
             'formulation',
             'stock_dilution',
+            'tags',
         ]
         if ('makemigrations' in sys.argv or 'migrate' in sys.argv or 'test' in sys.argv):
             fields.remove('manufacturer')
+
     def __init__(self, *args, **kwargs):
         super(TonerForm, self).__init__(*args, **kwargs)
         self.helper = FormHelper(self)
